#include <stdio.h>
#include <ownetapi.h>

#include "parser.h"
#include "debug.h"
#include "string.h"

int parse_opts(const char *str, char *ow_path, size_t pathlen, double *offset)
{
	char *endptr;
	const char *start_str = str;
	const char offset_str[] = "offset=";

	if (!offset)
		return 0;

	/*
	 * Skip the onewire path entry. Options begin after the first
	 * white space
	 */
	for (; *str; str++)
		if (isspace(*str))
			break;

	/* Copy the onewire path without options */
	strncpy(ow_path, start_str, pathlen);
	ow_path[str - start_str] = '\0';

	/* Get the next non-space, which is where the argument begins */
	for (; *str; str++)
		if (!isspace(*str))
			break;

	if (strncmp(str, offset_str, sizeof(offset_str) - 1))
		return 0;
	str += sizeof(offset_str) - 1;

	*offset = strtod(str, &endptr);

	if (str != endptr)
		return 1;

	return 0;
}

int onewire_parser(char *rrd_data, const char **parser_data)
{
	OWNET_HANDLE h;
	const char *server_addr;
	char buf[24], *tmp;
	int i = 1, ret;
	int max_str = RRD_DATA_MAX_LEN;

	if (!parser_data) {
		pr_err("No parser data available\n");
		return -1;
	}

	server_addr = parser_data[0];

	if (!server_addr) {
		pr_err("Server address not specified\n");
		return -1;
	}

	h = OWNET_init(server_addr);
	if (h < 0) {
		pr_err("Failed to connect to server %s\n", server_addr);
		return -1;
	}

	while (parser_data[i]) {
		double offset = 0, data;
		char *endptr;
		char ow_path[1024];

		if (!strcmp("U", parser_data[i])) {
undefined:
			ret = snprintf(rrd_data, max_str, "U");
			max_str -= ret;
			rrd_data += ret;
			goto next;
		}

		parse_opts(parser_data[i], ow_path, sizeof(ow_path), &offset);

		pr_info("Reading data for entry %s with offset of %.2f\n",
			ow_path, offset);
		ret = OWNET_read(h, ow_path, &tmp);
		if (ret < 0) {
			pr_err("Failed to read entry %s\n", parser_data[i]);
			goto undefined;
		}

		/* The data from OWNET_read appears to not be NULL terminated */
		memcpy(buf, tmp, MIN(ret, sizeof(buf) -1));
		free(tmp);
		buf[ret] = 0;

		data = strtod(buf, &endptr);

		if (endptr == buf) {
			pr_err("Failed to parse data %s\n", buf);
			goto undefined;
		}

		data += offset;

		ret = snprintf(rrd_data, max_str, "%f", data);
		max_str -= ret;
		rrd_data += ret;

next:
		i++;
		if (!parser_data[i])
			break;

		ret = snprintf(rrd_data, max_str, ":");
		max_str -= ret;
		rrd_data += ret;
	}
	rrd_data = 0;

	OWNET_finish();
	return 0;
}
